Crate contained_derive

Crate contained_derive 

derive macros for the contained crate

Derive Macros

Get
The Get derive macros is designed to streamline the process of creating getter methods for structs. Coupled with the custom attributes, one can toggle the generation of mutable getters and define alternative method names for accessing the inner value.
SetWith
The SetWith macros is used to generate setter methods for struct fields.
Wrapper
The Wrapper macro is designed for single-field structs, implementing additional methods supporting interactions with the inner value