Get

Derive Macro Get 

#[derive(Get)]
{
    // Attributes available to this derive:
    #[gsw]
}
The Get derive macros is designed to streamline the process of creating getter methods for structs. Coupled with the custom attributes, one can toggle the generation of mutable getters and define alternative method names for accessing the inner value.