derive macros for the contained crate
Derive Macros
- Get
- The
Getderive macros is designed to streamline the process of creating getter methods for structs. Coupled with the custom attributes, one can toggle the generation of mutable getters and define alternative method names for accessing the inner value. - SetWith
- The
SetWithmacros is used to generate setter methods for struct fields. - Wrapper
- The
Wrappermacro is designed for single-field structs, implementing additional methods supporting interactions with the inner value